function [DutyCycleCellProb,Power]=DutyCycleCellProb(Power,DutyCycles,numDay)
% This function generate the matrix of % of cycles occurred weekly
%{
 Input : 
       Power - 17520 hourly optimal power input/ output result from Dispatcher
       DutyCycles - matrix contains all types of duty cycles, regardless of resting time
                    The matrix obtained from DutyCycleGenerator

 Output : 
       DutyCycleCellProb - contains 104 rows, which is total of 104 weeks in 2 years
                           The number of columns is the number of unique
                           types from DutyCycles matrix
       Power - Reshape the power vector into weekly data (104x168)
%}

Power=round(Power,4);
T=numel(Power);          % Total number of hours
numPeriod = T/numDay;
numWeek=floor(numDay/7); % Total number of full weeks
Power=reshape(Power(1:numWeek*numPeriod*7),numPeriod*7,numWeek)';
DutyCycleInd=nan(numWeek,7); % 104x7 days
for i=1:size(Power,1)
    power = reshape(Power(i,:),numPeriod,7)';
    for k=1:7
        d=power(k,:); % d = 24 hours in a day
        cycle=[];
    if d(1)~=0
        cycle=d(1);
    end;
    for j=2:numPeriod
        if d(j)==0
            cycle=cycle;
        elseif (d(j)==d(j-1) && length(cycle)==1 && d(j)~=0)
            cycle=cycle+d(j);
        elseif (d(j)==d(j-1) && length(cycle)>1 && d(j)~=0)
            cycle=[cycle(1:end-1) cycle(end)+d(j)];
        elseif (d(j)~=d(j-1) && d(j)~=0)
            cycle=[cycle d(j)];
        end;
    end;
    dutycycle=[cycle zeros(1,numPeriod-length(cycle))];
    [DutyCycleInd(i,k),~]=find(ismember(DutyCycles,dutycycle,'rows')); % Find the type of duty cycle matches
    end;
end;

% Produce the matrix contains the probabilities of each type of duty cycles
% occurred in each week
DutyCycleCellProb=nan(numWeek,size(DutyCycles,1));
for i=1:numWeek 
    dutycycleind=DutyCycleInd(i,:);
    for j=1:size(DutyCycles,1)
        DutyCycleCellProb(i,j)=sum(dutycycleind==j)/7;
    end;
end;
